@@ -10,7 +10,7 @@
 
       CHARACTER CPARA*8,CDSN*80
 
-      EXTERNAL  LENC,IUFOPN
+      EXTERNAL  IUFOPN
 
       SAVE
 
