@@ -5,7 +5,8 @@
 
       CHARACTER CMSG*80
 
-      EXTERNAL  LENY,LENZ,INDXMF,IFROMC,FFROMC
+*     EXTERNAL  LENY,LENZ,INDXMF,IFROMC,FFROMC
+      EXTERNAL  LENZ,INDXMF,IFROMC,FFROMC
 
 
 *     LC1=LENY(CX)+1
